<p align="center">
    <img src="https://picreso.oss-cn-beijing.aliyuncs.com/airs.png" width="150px">
    <h1 align="center"><img src="http://picreso.oss-cn-beijing.aliyuncs.com/fonts.png" /></h1>
    <div align="center">
		<img src="https://picreso.oss-cn-beijing.aliyuncs.com/ruia.svg">
    <img src="https://picreso.oss-cn-beijing.aliyuncs.com/ruia-20200607165029224.svg">
    <img src="https://picreso.oss-cn-beijing.aliyuncs.com/ruia-20200607165030320.svg">
    </div>
    <br>
    <p align="center" style="font-weight:bold">
        Distributed🌍  -  Asynchronous🏃  -  Light☁️  -  Fast⚡️ - Easy😄
      <br>
       <br>
     		AirSpider🕷️, a Light and Fast Python Web Crawler Framework Based on Redis🕷️
      <img src="http://picreso.oss-cn-beijing.aliyuncs.com/codepreview.png">
</p>    

---

## Overview👀

> + **AirSpider** is a high-performance asynchronous crawler framework for developers 🚀
> + Based on Redis: task distribution, task deduplication, and distributed ☁️
>

## Requirements☁️

- Python 3.6➕
- Works on Linux, Windows, macOS🍎

## Features🌲

+ **Quick to Start ☑️**
+ **Low Coupling ☑️**
+ **High Cohesion ☑️**
+ **Easy Expansion ☑️**
+ **Orderly Workflow ☑️**

## Installation🔨

``` shell
---------------------------

# For Linux && MacOS🔥
pip3 install airspider

---------------------------

# For Windows🔥
pip3 install airspider

---------------------------
```

## Documents🔥

+ [Quick Start](#)🕷️
+ [API Guide](#)👨‍🎓
+ [Plugins](#)🔨
+ [Examples](#)☁️
+ [Architecture](https://github.com/xunzhuo/AirSpider/blob/master/Docs/architecture.md)🏠

## TODO✈️

+ Complete Plugins of Redis🔥
+ Complete Distributed Architecture☁️

## Contributing👬

**AirSpider**🕷️ is still under **Developing**🔨

> Feel free to open issues💬 and pull requests💗

- Report or Fix bugs🌈
- Build Powerful plugins🔥
- Make documentation Better📖
- Add Examples of Crawling 🕷️

![](http://picreso.oss-cn-beijing.aliyuncs.com/monkey.jpg)